@@ -47,6 +47,8 @@ __PACKAGE__->set_primary_key("mac");
 
 =head2 oui
 
+DEPRECATED: USE MANUFACTURER INSTEAD
+
 Returns the C<oui> table entry matching this Node. You can then join on this
 relation and retrieve the Company name from the related table.
 
@@ -65,6 +67,26 @@ __PACKAGE__->belongs_to( oui => 'App::Netdisco::DB::Result::Oui',
     { join_type => 'LEFT' }
 );
 
+=head2 manufacturer
+
+Returns the C<manufacturer> table entry matching this Node. You can then join on this
+relation and retrieve the Company name from the related table.
+
+The JOIN is of type LEFT, in case the Manufacturer table has not been populated.
+
+=cut
+
+__PACKAGE__->belongs_to( manufacturer => 'App::Netdisco::DB::Result::Manufacturer',
+  sub {
+      my $args = shift;
+      return {
+        "$args->{foreign_alias}.range" => { '@>' =>
+          \qq{('x' || lpad( translate( $args->{self_alias}.mac ::text, ':', ''), 16, '0')) ::bit(64) ::bigint} },
+      };
+  },
+  { join_type => 'LEFT' }
+);
+
 =head2 nodes
 
 Returns the set of C<node> entries associated with this IP. That is, all the
