@@ -20,7 +20,7 @@ get '/ajax/content/report/apradiochannelpower/data' => require_login sub {
     send_error( 'Missing parameter', 400 )
         unless ( param('draw') && param('draw') =~ /\d+/ );
 
-    my $rs = schema('netdisco')->resultset('Virtual::ApRadioChannelPower');
+    my $rs = schema(vars->{'tenant'})->resultset('Virtual::ApRadioChannelPower');
     my $exp_params = expand_hash( scalar params );
     my $recordsTotal = $rs->count;
     my @data = $rs->get_datatables_data($exp_params)->hri->all;
@@ -43,7 +43,7 @@ get '/ajax/content/report/apradiochannelpower' => require_login sub {
     }
     else {
         my @results
-            = schema('netdisco')->resultset('Virtual::ApRadioChannelPower')
+            = schema(vars->{'tenant'})->resultset('Virtual::ApRadioChannelPower')
             ->hri->all;
 
         return unless scalar @results;
