@@ -87,14 +87,13 @@ register_worker({ phase => 'early', driver => 'snmp',
 
   my $enterprises_mib = qr/(?:\.?1.3.6.1.4.1|enterprises)\.\d+/;
   my $try_vendor =
-    ($device->id and $device->id =~ m/^${enterprises_mib}/) ? $device->id
+    ($snmp->id and $snmp->id =~ m/^${enterprises_mib}/) ? $snmp->id
     : ($device->model and $device->model =~ m/^${enterprises_mib}/) ? $device->model
-    : ($device->vendor and $device->vendor =~ m/^${enterprises_mib}/) ? $device->vendor
     : undef;
   $try_vendor =~ s/^(?:\.?1.3.6.1.4.1|enterprises)// if $try_vendor;
 
   # fix up unknown vendor (enterprise number -> organization)
-  if ($try_vendor and $try_vendor =~ m/^\.(\d+)/) {
+  if (not $device->vendor and $try_vendor and $try_vendor =~ m/^\.(\d+)/) {
       my $number = $1;
       debug sprintf ' searching for Enterprise Number "%s"', $number;
       my $ent = schema('netdisco')->resultset('Enterprise')->find($number);
@@ -104,13 +103,14 @@ register_worker({ phase => 'early', driver => 'snmp',
       }
   }
 
-  # fix up unknown model using products OID cache
+  # fix up model using products OID cache
   if ($try_vendor) {
       my $oid = '.1.3.6.1.4.1' . $try_vendor;
       debug sprintf ' searching for Product ID "%s"', ('enterprises' . $try_vendor);
       my $object = schema('netdisco')->resultset('Product')->find($oid);
       if ($object) {
-          debug sprintf ' ... found Product "%s"', $object->leaf;
+          debug sprintf ' ... found Product "%s" (replaced "%s")',
+            $object->leaf, ($device->model || '');
           $device->set_column( model => $object->leaf );
       }
   }
